#!/bin/ksh

# Basic script that takes in arguments from an amqpfind command and runs McIDAS commands

ROOT_DIR=$HOME/remap
export ROOT_DIR
if [[ ! -d "${ROOT_DIR}" ]];then
    mkdir ${ROOT_DIR}
fi

LOG_DIR=${ROOT_DIR}/log
export LOG_DIR
if [[ ! -d "${LOG_DIR}" ]];then
    mkdir ${LOG_DIR}
fi

export LOG=${LOG_DIR}/remap_script.log
exec >>$LOG
exec 2>>$LOG

DATA_DIR=${ROOT_DIR}/data
export DATA_DIR
if [[ ! -d "${DATA_DIR}" ]];then
    mkdir -p ${DATA_DIR}
fi

MCPATH=${DATA_DIR}:/home/mcidas/data
export MCPATH

DAY=$1
TIME=$2
ADDE_DATASET=$3
ADDE_SERVER=$4
SATELLITE=$5
COVERAGE=$6

# McIDAS does not deal with fractional times
TIME="$(date -d ${TIME} +%H:%M:%S)"
export DAY TIME BAND ADDE_DATASET ADDE_SERVER SATELLITE_LOCATION

# Split apart the adde data
ADDE_GROUP="$(echo ${ADDE_DATASET}| cut -d'/' -f1)"
ADDE_DESCRIPTOR="$(echo ${ADDE_DATASET} | cut -d'/' -f2)"
export ADDE_DESCRIPTOR ADDE_GROUP
echo ${ADDE_DATASET}
echo ${ADDE_GROUP}
echo ${ADDE_DESCRIPTOR}

# Define a local ADDE datasets
IMGCOPY_DATASET=IMGCOPY/AREAS
IMGREMAP_DATASET=IMGREMAP/AREAS
export IMGCOPY_DATASET IMGREMAP_DATASET

# Make the script a little easier to update if you need to update center point and size
REMAP_LAT='45:30:00'
REMAP_LON='085:30:00'
RES='3.5'
REMAP_LINES=970
REMAP_ELES=1100
PROJECTION='PS'
BAND=13
export REMAP_LAT REMAP_LON RES REMAP_LINES REMAP_ELES PROJECTION BAND

# Generate a day/time based file name - first remove quotes from time
FILE_TIME="$(echo ${TIME} | tr -d ':')"
export FILE_TIME
FILENAME=${SATELLITE}_sector_001_${DAY}_${FILE_TIME}.gif
export FILENAME

# SSEC needs user initials and project number
MCUSER=Satellite Data Services User Initials
MCPROJ=Satellite Data Services Project number
export MCUSER MCPROJ

# Startup McIDAS
mcenv -i 200 -f 1@${REMAP_LINES}x${REMAP_LINES} << 'EOF'

    logon.k ${MCUSER} ${MCPROJ}

    # Define local dataset
    dsserve.k ADD ${IMGCOPY_DATASET} AREA 1001 1010
    dsserve.k ADD ${IMGREMAP_DATASET} AREA 1011 1011

    # Setup MCTABLE entry
    dataloc.k ADD $ADDE_GROUP ${ADDE_SERVER}

    # One way of guarding agains processing the data more than one time is to first use IMGCOPY 
    # to copy down a tiny 4x4 part of the dataset into the LOCAL_DATASET. If the date/time already
    # exists, you don't process the data. 
    mceval.k IMGCOPY ${ADDE_DATASET} ${IMGCOPY_DATASET} SIZE=4 4 BAND=${BAND}
    ret=$?

    if [[ $ret -ne 0 ]]; then
        exit
    fi

    mceval.k IMGREMAP ${ADDE_DATASET} ${IMGREMAP_DATASET}.1 LATLON=${REMAP_LAT} ${REMAP_LON} SIZE=${REMAP_LINES} ${REMAP_ELES} PRO=${PROJECTION} RES=${RES} BAND=${BAND}

    mceval.k IMGDISP ${IMGREMAP_DATASET}.1
    mceval.k MAP
    mceval.k FRMLABEL \"${SATELLITE_LOCATION} \(BAND\) SECTOR 001 \(DAY\) \(HHMMSS\)
    mceval.k FRMSAVE X ${FILENAME}

exit 0
EOF

exit 0
